## Overview

The subdirectories pertain to the Resource Management Layer (RML).

## Directories

include/

  Include files used by clients of RML.

client/

  Source files for code that must be statically linked with a client.

server/

  Source files for the RML server.

test/

  Unit tests for RML server and its components.

Up to parent directory

Copyright © 2005-2020 Intel Corporation. All Rights Reserved.

Intel is a registered trademark or trademark of Intel Corporation or its subsidiaries in the United States and other countries.

* Other names and brands may be claimed as the property of others.